//
//  AASLoadingOperation.h
//  AASFilesystemTools
//
//  Created by Andreas Schwarz on 3/12/08.
//  OS X 10.5 or later required.
/* Copyright (c) 2001-2009, Andreas Schwarz
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
 Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 Neither the names of the Andreas Schwarz or immaterial nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* AASLoadingOperation is a subclass of NSOperation that has some basic support for an array in which to load objects from the worker thread, and locks to safely work with that array in both the worker thread and the client thread. It is used as a basis for the AASFileLoadOperation class, but can be useful as the basis for any number of similar operations. Like NSOperation, AASLoadingOperation cannot be used on its own, it must be subclassed. */

#import <Cocoa/Cocoa.h>


@interface AASLoadingOperation : NSOperation {
	NSLock *loadingArrayLock;
	NSMutableArray *loadingArray;
}


/* Set or get the lock to use when manipulating the loading array and events array. Do not set after the operation has been added to an operation queue. */
@property(retain) NSLock *loadingArrayLock;

/* Set or get the array for that the operation is filling with objects. Do not set after the operation has been added to an operation queue, and always use the loadingArrayLock when accessing or modifying the array until the operation is finished. */
@property(retain) NSMutableArray *loadingArray;


@end
